ExitCode enum
CLI exit codes.
Error codes follow the POSIX conventions in sysexits.h.
Values
- success → const ExitCode
-
Successful execution.
const ExitCode(0) - changed → const ExitCode
-
Files were changed (used with
--set-exit-if-changed).const ExitCode(1) - usage → const ExitCode
-
Invalid command-line usage (
EX_USAGE).const ExitCode(64) - error → const ExitCode
-
A file or directory could not be processed (
EX_DATAERR).const ExitCode(65) - software → const ExitCode
-
An unexpected internal error occurred (
EX_SOFTWARE).const ExitCode(70)
Properties
- code → int
-
The numeric exit code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited